@@ -1,8 +1,8 @@
-### xtable 1.3-0  (2005/11/02)
+### xtable 1.3-1  (2006/04/04)
 ###
 ### Produce LaTeX and HTML tables from R objects.
 ###
-### Copyright 2000-2005 David B. Dahl <dahl@stat.tamu.edu>
+### Copyright 2000-2006 David B. Dahl <dahl@stat.tamu.edu>
 ###
 ### This file is part of the `xtable' library for R and related languages.
 ### It is made available under the terms of the GNU General Public
@@ -187,16 +187,17 @@ xtable.coxph <- function (x,caption=NULL,label=NULL,align=NULL,vsep=NULL,
   cox <- x
   beta <- cox$coef
   se <- sqrt(diag(cox$var))
-#  DBD: Nov 2, 2005:  Commented out this if/else statement because "nse" is never defined!
-#  if (is.null(cox$naive.var)) {
+  if (is.null(cox$naive.var)) {
     tmp <- cbind(beta, exp(beta), se, beta/se, 1 - pchisq((beta/se)^2, 1))
     dimnames(tmp) <- list(names(beta),
       c("coef", "exp(coef)", "se(coef)", "z", "p"))
-#  }
-#  else {
-#    tmp <- cbind( beta, exp(beta), nse, se, beta/se, signif(1 - pchisq((beta/se)^2, 1), digits - 1))
-#    dimnames(tmp) <- list(names(beta),c("coef", "exp(coef)", "se(coef)", "robust se", "z", "p"))
-#  }
+  }
+  else {
+    tmp <- cbind( beta, exp(beta), nse, se, beta/se,
+      signif(1 - pchisq((beta/se)^2, 1), digits - 1))
+    dimnames(tmp) <- list(names(beta),
+      c("coef", "exp(coef)", "se(coef)", "robust se", "z", "p"))
+  }
   return(xtable(tmp, caption = caption, label = label, align = align,
                 vsep = vsep, digits = digits, display = display))
 }
